@@ -13,7 +13,7 @@ class TQSpinBox;
 
 class ConfigureDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	ConfigureDialog(TQWidget *parent = 0, char *name = 0, bool modal = 0);
